"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lifecycle_1 = require("@pnpm/lifecycle");
const read_importer_manifest_1 = require("@pnpm/read-importer-manifest");
const utils_1 = require("@pnpm/utils");
async function run(args, opts) {
    const manifest = await read_importer_manifest_1.readImporterManifestOnly(opts.prefix);
    const scriptName = args[0];
    if (scriptName !== 'start' && (!manifest.scripts || !manifest.scripts[scriptName])) {
        const err = new Error(`Missing script: ${scriptName}`);
        err['code'] = 'ERR_PNPM_NO_SCRIPT';
        throw err;
    }
    const dashDashIndex = opts.argv.cooked.indexOf('--');
    const lifecycleOpts = {
        args: dashDashIndex === -1 ? [] : opts.argv.cooked.slice(dashDashIndex + 1),
        depPath: opts.prefix,
        pkgRoot: opts.prefix,
        rawNpmConfig: opts.rawNpmConfig,
        rootNodeModulesDir: await utils_1.realNodeModulesDir(opts.prefix),
        stdio: 'inherit',
        unsafePerm: true,
    };
    if (manifest.scripts && manifest.scripts[`pre${scriptName}`]) {
        await lifecycle_1.default(`pre${scriptName}`, manifest, lifecycleOpts);
    }
    await lifecycle_1.default(scriptName, manifest, lifecycleOpts);
    if (manifest.scripts && manifest.scripts[`post${scriptName}`]) {
        await lifecycle_1.default(`post${scriptName}`, manifest, lifecycleOpts);
    }
}
exports.default = run;
async function start(args, opts) {
    return run(['start', ...args], opts);
}
exports.start = start;
async function stop(args, opts) {
    return run(['stop', ...args], opts);
}
exports.stop = stop;
async function test(args, opts) {
    return run(['test', ...args], opts);
}
exports.test = test;
async function restart(args, opts) {
    await stop(args, opts);
    await run(['restart', ...args], opts);
    await start(args, opts);
}
exports.restart = restart;
//# sourceMappingURL=run.js.map